import React, { useState } from 'react';
import { render } from 'react-dom';
import GraphiQL from '@tyk-technologies/graphiql';

const TykGraphiqlExplorer = ({ url, schema }) => {
  const [headers, setHeaders] = useState('');

  const handleHeaderEdit = (headerStr) => {
    try {
      const tempHeaders = JSON.parse(headerStr);
      setHeaders(tempHeaders);
    } catch (error) {
      return;
    }
  };

  const fetcher = async (graphQLParams) => {
    const data = await fetch(url, {
      method: 'POST',
      headers: {
        Accept: 'application/json',
        'Content-Type': 'application/json',
        ...headers,
      },
      body: JSON.stringify(graphQLParams),
      credentials: 'same-origin',
    });
    return data.json().catch(() => data.text());
  };

  return (
    <GraphiQL
      fetcher={fetcher}
      ideName={'TYK'}
      schema={schema}
      onEditHeaders={handleHeaderEdit}
      headerEditorEnabled
      shouldPersistHeaders
    />
  );
};

class GraphiqlInit {
  constructor(config) {
    const { containerId, url, schema } = config;
    render(
      <TykGraphiqlExplorer url={url} schema={schema} />,
      document.getElementById(containerId)
    );
  }
}

window.GraphiqlInit = GraphiqlInit;
